@font-face {
  font-family: 'Open Sans';
  src: url('../xstatic/fonts/Regular/OpenSans-Regular.eot?#iefix') format('embedded-opentype'), url('../xstatic/fonts/Regular/OpenSans-Regular.woff') format('woff'), url('../xstatic/fonts/Regular/OpenSans-Regular.ttf') format('truetype'), url('../xstatic/fonts/Regular/OpenSans-Regular.svg#fontawesomeregular') format('svg');
  font-weight: normal;
  font-style: normal;
}

@font-face {
  font-family: 'Open Sans';
  src: url('../xstatic/fonts/Bold/OpenSans-Bold.eot?#iefix') format('embedded-opentype'), url('../xstatic/fonts/Bold/OpenSans-Bold.woff') format('woff'), url('../xstatic/fonts/Bold/OpenSans-Bold.ttf') format('truetype'), url('../xstatic/fonts/Bold/OpenSans-Bold.svg#fontawesomeregular') format('svg');
  font-weight: bold;
  font-style: normal;
}
