@font-face {
	font-family: 'FontAwesome';
	src: url('../xstatic/fonts/fontawesome-webfont.eot');
	src: url('../xstatic/fonts/fontawesome-webfont.eot?#iefix') format('embedded-opentype'), url('../xstatic/fonts/fontawesome-webfont.woff') format('woff'), url('../xstatic/fonts/fontawesome-webfont.ttf') format('truetype'), url('../xstatic/fonts/fontawesome-webfont.svg#fontawesomeregular') format('svg');
	font-weight: normal;
	font-style: normal;
}

@mixin vendor-prefix($name, $value) {
	@each $vendor in ('-webkit-', '-moz-', '-ms-', '-o-', '') {
		#{$vendor}#{$name}: #{$value};
	}
}

@function text-color($color) {
  @if (lightness($color) > 50) {
    @return #303030;
  } @else {
    @return #ffffff;
  }
}
