@font-face {
  font-family: 'Open Sans';
  src: url("../xstatic/fonts/Regular/OpenSans-Regular.eot?#iefix") format("embedded-opentype"), url("../xstatic/fonts/Regular/OpenSans-Regular.woff") format("woff"), url("../xstatic/fonts/Regular/OpenSans-Regular.ttf") format("truetype"), url("../xstatic/fonts/Regular/OpenSans-Regular.svg#fontawesomeregular") format("svg");
  font-weight: normal;
  font-style: normal; }
@font-face {
  font-family: 'Open Sans';
  src: url("../xstatic/fonts/Bold/OpenSans-Bold.eot?#iefix") format("embedded-opentype"), url("../xstatic/fonts/Bold/OpenSans-Bold.woff") format("woff"), url("../xstatic/fonts/Bold/OpenSans-Bold.ttf") format("truetype"), url("../xstatic/fonts/Bold/OpenSans-Bold.svg#fontawesomeregular") format("svg");
  font-weight: bold;
  font-style: normal; }
@font-face {
  font-family: 'FontAwesome';
  src: url("../xstatic/fonts/fontawesome-webfont.eot");
  src: url("../xstatic/fonts/fontawesome-webfont.eot?#iefix") format("embedded-opentype"), url("../xstatic/fonts/fontawesome-webfont.woff") format("woff"), url("../xstatic/fonts/fontawesome-webfont.ttf") format("truetype"), url("../xstatic/fonts/fontawesome-webfont.svg#fontawesomeregular") format("svg");
  font-weight: normal;
  font-style: normal; }
/* generalities */
html, body {
  margin: 0;
  font-family: "Open Sans", sans-serif;
  font-size: 12px;
  background: #f2f2f2;
  color: #3c3c33; }

html {
  min-height: 100%;
  position: relative; }

body {
  height: 100%; }

a {
  color: #0066cc;
  text-decoration: none;
  border-width: 0;
  border-bottom: 1px dotted #ff9900;
  -webkit-transition: color 200ms ease-out;
  -moz-transition: color 200ms ease-out;
  -ms-transition: color 200ms ease-out;
  -o-transition: color 200ms ease-out;
  transition: color 200ms ease-out; }
  a:hover {
    color: #003388;
    border-style: solid; }
  a img {
    border: 0; }
  a.disabled {
    color: #aaa;
    border: none;
    cursor: default; }

dl dt {
  margin: 0;
  padding: 0 0 0 0; }

dl dd {
  margin: 0.3em 0 1.5em 10px; }

span.error-message {
  color: #e00;
  font-weight: bold; }

span.warning {
  background-color: orange; }

.clear {
  clear: both; }

/* from top to bottom */
/* top bar */
div#top {
  color: #eee;
  height: 0px; }

div#top a {
  color: #aaa;
  font-weight: normal;
  border: 0; }
  div#top a:hover {
    color: #888; }

ul.user-info {
  margin: 0;
  padding: 0;
  padding-right: 3em;
  font-size: 85%;
  font-weight: bold;
  position: absolute;
  top: 0px;
  right: 0px;
  z-index: 10;
  background: #23282d url(texture.png);
  height: 40px;
  line-height: 40px; }
  ul.user-info li {
    display: inline;
    padding-left: 3em; }

/* header */
div#header {
  background: #C2D1CC url(header-03.jpeg);
  background-size: 100% 500px;
  padding-left: 0px;
  border-bottom: 1px solid #888;
  position: relative;
  height: 40px; }

div#header h1 {
  height: 40px;
  line-height: 40px;
  padding: 0 41px 0 20px;
  margin: 0;
  font-weight: normal;
  color: black;
  text-shadow: 0 0 2px white;
  display: inline-block;
  z-index: 100;
  max-width: 80%;
  width: 80%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all ease 200ms;
  -moz-transition: all ease 200ms;
  -ms-transition: all ease 200ms;
  -o-transition: all ease 200ms;
  transition: all ease 200ms;
  opacity: 0.5; }
  div#header h1 a {
    color: inherit;
    border-bottom: none;
    display: inline-block;
    padding: 0 11px;
    position: relative;
    margin-left: -5px;
    padding-left: 20px; }
    div#header h1 a:first-child {
      padding-left: 0; }
  div#header h1:hover {
    opacity: 0.7; }
  div#header h1 a:hover {
    opacity: 1;
    text-shadow: 0 0 0px #333; }

div#header h1.breadcrumbs a:last-child {
  /* hide last breadcrumb item (== current page) */
  display: none; }
div#header h1.breadcrumbs span.separator {
  display: none; }
div#header h1.breadcrumbs a::after {
  content: "";
  height: 42px;
  width: 42px;
  -webkit-transform: scale(0.4, 0.707) rotate(45deg);
  -moz-transform: scale(0.4, 0.707) rotate(45deg);
  -ms-transform: scale(0.4, 0.707) rotate(45deg);
  -o-transform: scale(0.4, 0.707) rotate(45deg);
  transform: scale(0.4, 0.707) rotate(45deg);
  display: inline-block;
  position: absolute;
  top: 0px;
  right: -21px;
  box-shadow: 1px -1px 0px 1px #bbb, 2px -2px 0px 2px white;
  z-index: 100;
  border-width: 1px 1px 0 0; }

body[data-environment-label] span#applabel {
  background-image: repeating-linear-gradient(-45deg, #333, black 14px, #ffe761 15px, #ffe761 29px, black 30px);
  color: white;
  text-shadow: 0 0 1px black; }

/* notifications */
ul.messages {
  padding: 0;
  margin: 0;
  list-style-type: none;
  max-width: 100ex;
  position: relative; }
  ul.messages li {
    font-size: 110%;
    background: #fafafa;
    margin: 1ex 0;
    padding: 1ex;
    border: 1px solid transparent;
    border-left-width: 25px; }
    ul.messages li:before {
      position: absolute;
      left: 0;
      width: 25px;
      display: inline-block;
      text-align: center;
      font-family: FontAwesome;
      color: white; }
    ul.messages li.success {
      /* check-circle */
      border-color: #0b0b0b; }
      ul.messages li.success:before {
        content: "\f058"; }
    ul.messages li.info {
      /* info-circle */
      border-color: #00b000; }
      ul.messages li.info:before {
        content: "\f05a"; }
    ul.messages li.warning {
      /* exclamation-circle */
      border-color: #ffb000; }
      ul.messages li.warning:before {
        content: "\f06a"; }
    ul.messages li.error {
      /* exclamation-triangle */
      border-color: #b00000; }
      ul.messages li.error:before {
        content: "\f071"; }
    ul.messages li .close {
      float: right;
      cursor: pointer;
      font-weight: bold;
      border: none;
      color: inherit; }

/* main content */
div#main-content {
  width: 100%;
  margin-left: 0;
  padding: 1em 6px 0 16px;
  border: 1px solid #ccc;
  border-width: 0 1px 1px 0;
  background: white;
  float: left;
  position: relative;
  overflow-x: auto;
  overflow-y: hidden;
  box-sizing: border-box; }

div#main-content h2 {
  font-weight: normal; }

/* breadcrumb */
div#more-user-links {
  font-size: 110%; }

div#more-user-links a,
div#more-user-links a:after {
  background: #ccc;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  border: 1px solid #bbb;
  -webkit-transition: background 0.5s;
  -moz-transition: background 0.5s;
  -ms-transition: background 0.5s;
  -o-transition: background 0.5s;
  transition: background 0.5s; }

div#more-user-links a {
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  padding: 4px 12px;
  border-radius: 2px;
  text-decoration: none;
  font-size: 90%;
  color: black; }

span#breadcrumb {
  display: inline-block;
  margin: 1ex 0; }

span#breadcrumb a {
  display: inline-block;
  padding-left: 20px;
  position: relative;
  height: 14px;
  margin-left: -4px; }

span#breadcrumb a:first-child {
  margin-left: 0;
  padding-left: 16px; }

span#breadcrumb a:after {
  content: "";
  height: 22px;
  width: 22px;
  -webkit-transform: scale(0.4, 0.707) rotate(45deg);
  -moz-transform: scale(0.4, 0.707) rotate(45deg);
  -ms-transform: scale(0.4, 0.707) rotate(45deg);
  -o-transform: scale(0.4, 0.707) rotate(45deg);
  transform: scale(0.4, 0.707) rotate(45deg);
  display: inline-block;
  position: absolute;
  top: 0px;
  right: -11px;
  box-shadow: 1px -1px 0px 1px #bbb, 2px -2px 0px 2px white;
  z-index: 100;
  border-width: 1px 1px 0 0; }

div#more-user-links a:hover,
div#more-user-links a:hover:after {
  text-decoration: underline;
  background: #aaa; }

/* page content */
div#content {
  margin: 0 1ex 1em 0;
  padding: 0px;
  position: relative; }

div#main-content > h2,
div#appbar > h2,
div#main-content .top-title h2,
div#content h2 {
  margin-top: 0;
  font-weight: normal;
  color: #656551;
  font-size: 200%;
  letter-spacing: -1px;
  line-height: 25px;
  margin-bottom: 20px;
  padding: 0 0 10px 0px;
  position: relative;
  top: 4px;
  border-bottom: 1px dotted #d8d8d8; }

div#appbar > a {
  position: relative;
  top: -45px;
  float: right;
  margin-left: 2em; }

table.main {
  width: 100%;
  border: 1px solid #bcbcbc;
  border-collapse: collapse; }

table.main th {
  font-weight: normal;
  padding: 1em 1ex;
  border-bottom: 1px solid #bcbcbc;
  background: #f0f0f0; }

table.main td {
  text-align: center;
  padding: 1em 1ex;
  border-bottom: 1px solid #bcbcbc; }

table.main tr td.checkbox {
  width: 1em; }

table.main tr:nth-child(even) td {
  background: #f5f5f5; }

table.main tr:hover td {
  background: #ccc;
  cursor: pointer; }

table.main tr.active td {
  background: #bbf; }

td.price {
  text-align: right; }

/* zone selection */
ul.apps {
  margin-top: 2em;
  margin-bottom: 2em;
  padding: 0; }

ul.apps li {
  display: table;
  float: left;
  margin-right: 1em;
  margin-bottom: 1em; }

ul.apps li a {
  background-color: transparent;
  background-repeat: no-repeat;
  background-position: 50% 50%;
  display: table-cell;
  vertical-align: bottom;
  width: 120px;
  height: 100px;
  padding-top: 10px;
  padding-bottom: 10px;
  font-weight: bold;
  text-align: center;
  border: 1px solid #ccc;
  text-decoration: none;
  -webkit-transition: all .2s ease-in-out;
  -moz-transition: all .2s ease-in-out;
  -ms-transition: all .2s ease-in-out;
  -o-transition: all .2s ease-in-out;
  transition: all .2s ease-in-out;
  color: #FF7800;
  border-radius: 15px; }

ul.apps li a:hover {
  border: 1px solid #333;
  color: #FF7800;
  border-radius: 25px; }

/* footer */
div#footer {
  clear: both;
  margin-left: 2%;
  font-size: 60%;
  width: 96%; }

/* icons */
[class^="icon-"]:after, [class*=" icon-"]:after,
[class^="icon-"]:before, [class*=" icon-"]:before {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  display: inline-block;
  text-decoration: none; }

a[class^="icon-"], a[class*=" icon-"] {
  display: inline-block;
  text-decoration: none;
  border: none;
  color: #FF7800; }

.icon-home-space:before {
  content: "\f015\00a0\00a0"; }

.icon-remove-sign:before {
  content: "\f057"; }

.icon-add-sign:before {
  content: "\f067"; }

.icon-minus-sign:before {
  content: "\f068"; }

/* misc */
div#content div.bo-block {
  margin-left: 0; }

div.bo-block {
  border: 1px solid #e4e4e4;
  background: #fcfcfc;
  color: #505050;
  margin: 1em 0;
  padding: 1ex; }

div.bo-block h2 {
  margin: 0;
  border-bottom: 1px solid #bcbcbc;
  color: #474747; }

div.dimmed-block h2 {
  color: #808080; }

div.bo-block ul {
  padding-left: 2em;
  padding-bottom: 1ex; }

div.big-msg-info {
  background: transparent url(../images/info-icon.png) 5px 5px no-repeat;
  width: 30em;
  padding-left: 90px;
  margin: 3em auto;
  min-height: 90px;
  padding-top: 20px; }

p.paginator {
  margin: 4ex 0; }

p.paginator *:first-child {
  border-radius: 3px 0 0 3px; }

p.paginator *:last-child {
  border-radius: 0 3px 3px 0; }

p.paginator a,
p.paginator span {
  padding: 1.5ex 1.7ex 1ex 1.7ex;
  border: 1px solid #BCBCBC;
  margin: 0 0 0 -1px; }

p.paginator span.this-page {
  background: #0066CC;
  border-color: #0066CC;
  color: white; }

p.paginator span.this-page + a {
  border-left-color: #0066CC; }

p.paginator a:hover {
  background: #eee; }

ul.objects-list {
  margin: 1em 0;
  padding: 0; }

ul.objects-list li {
  list-style: none;
  margin: 0 0 -1px 0;
  padding: 0 0.5ex 0 2ex;
  border: 1px solid #aaa;
  clear: both;
  position: relative;
  min-height: 2.5em;
  line-height: 2.5em; }

ul.objects-list.single-links li {
  padding: 0; }

ul.objects-list li:hover {
  background: #eee; }

ul.objects-list.single-links li a {
  display: block;
  border: none;
  padding: 0 0.5ex 0 2ex; }

ul.objects-list li span.badge {
  position: absolute;
  right: 1ex;
  top: 0.25em;
  height: 2em;
  box-sizing: border-box;
  border-radius: 1ex;
  padding: 0 1ex;
  background: #ad7c6d;
  color: white;
  line-height: 2em; }

/* widgets & dialogs */
input[type="submit"][name="submit"] {
  background: #283c54;
  background-image: linear-gradient(to bottom, #1cabe7, #1999cd);
  color: white;
  border-color: #267dae; }

input[type=submit]:hover {
  border-color: #666; }

#sidepage {
  position: absolute;
  top: 0px;
  z-index: 100;
  width: 36px;
  height: 2em;
  text-align: left;
  -webkit-transition: all 0ms ease-in;
  -moz-transition: all 0ms ease-in;
  -ms-transition: all 0ms ease-in;
  -o-transition: all 0ms ease-in;
  transition: all 0ms ease-in;
  height: 100%;
  overflow: initial;
  background: #23282d url(texture.png); }

body[data-has-sidebar] #main {
  margin-left: 36px; }

body #main.sidepage-expanded {
  margin-left: 30ex; }

#main.enable-transitions,
#main.enable-transitions div#header h1,
#sidepage.enable-transitions ul#sidepage-menu,
#sidepage.enable-transitions span#applabel,
#sidepage.enable-transitions {
  -webkit-transition-duration: 400ms;
  -moz-transition-duration: 400ms;
  -ms-transition-duration: 400ms;
  -o-transition-duration: 400ms;
  transition-duration: 400ms; }

#sidepage.sidepage-expanded {
  height: 100%;
  overflow: initial;
  width: 30ex; }

#sidepage ul#sidepage-menu {
  transform: scale(1); }

#main {
  -webkit-transition: margin-left 0ms ease-in;
  -moz-transition: margin-left 0ms ease-in;
  -ms-transition: margin-left 0ms ease-in;
  -o-transition: margin-left 0ms ease-in;
  transition: margin-left 0ms ease-in;
  position: relative; }

#sidepage span#applabel {
  visibility: hidden;
  /* will be turned visible by publik.js */
  padding-left: 0.5rem;
  font-weight: bold;
  cursor: pointer;
  display: block;
  position: relative;
  overflow: hidden;
  -webkit-transition: max-width 0ms ease-in;
  -moz-transition: max-width 0ms ease-in;
  -ms-transition: max-width 0ms ease-in;
  -o-transition: max-width 0ms ease-in;
  transition: max-width 0ms ease-in;
  height: 40px;
  line-height: 40px;
  font-weight: normal;
  font-size: 20px;
  border-bottom: 1px solid #666; }
  #sidepage span#applabel:hover {
    color: #fff; }

#sidepage span#applabel::before {
  font-family: FontAwesome;
  content: "\f18e";
  /* fa-arrow-circle-o-right */
  padding-left: 2px;
  padding-right: 12px; }

#sidepage.sidepage-expanded span#applabel::before {
  content: "\f190";
  /* fa-arrow-circle-o-left */ }

#sidepage.sidepage-expanded span#applabel {
  overflow: hidden;
  max-width: 100%; }

#sidepage ul#sidepage-menu {
  list-style: none;
  padding: 0;
  padding-top: 1em;
  margin: 0;
  background: #23282d url(texture.png);
  min-height: 100%;
  min-height: calc(100% - 41px);
  /* #top 40px + border 1px */
  box-sizing: border-box;
  -webkit-transition: all 0ms ease;
  -moz-transition: all 0ms ease;
  -ms-transition: all 0ms ease;
  -o-transition: all 0ms ease;
  transition: all 0ms ease; }

#sidepage ul#sidepage-menu a {
  border: none;
  display: block;
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden; }

#sidepage ul#sidepage-menu li {
  position: relative;
  line-height: 24px; }

ul#sidepage-menu li a {
  background: transparent no-repeat 7px 50%;
  padding: 5px 0 5px 37px; }

#sidepage ul#sidepage-menu .active a {
  color: #eee; }

#sidepage ul#sidepage-menu li.active,
#sidepage ul#sidepage-menu li.active:hover {
  background: #215D9C; }

#sidepage ul#sidepage-menu li:after {
  background: rgba(0, 0, 0, 0.3);
  content: "";
  position: absolute;
  z-index: -1;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  -ms-transition: all 0.2s ease;
  -o-transition: all 0.2s ease;
  transition: all 0.2s ease;
  box-sizing: border-box;
  width: 0;
  width: 0%;
  height: 100%;
  top: 0;
  left: 0; }

#sidepage ul#sidepage-menu li:hover:after {
  width: 100%;
  height: 100%; }

#sidepage ul#sidepage-menu li.active:after {
  content: "";
  position: absolute;
  display: block;
  top: 0;
  background: white;
  z-index: 5;
  right: -17px;
  left: auto;
  width: 34px;
  height: 34px;
  -webkit-transform: scale(0.2, 0.2) rotate(45deg);
  -moz-transform: scale(0.2, 0.2) rotate(45deg);
  -ms-transform: scale(0.2, 0.2) rotate(45deg);
  -o-transform: scale(0.2, 0.2) rotate(45deg);
  transform: scale(0.2, 0.2) rotate(45deg); }

#gadjo-ajax-error {
  position: fixed;
  right: 1em;
  bottom: 1em;
  max-width: 30em;
  background: #ff2222 none repeat scroll 0% 0%;
  padding: 1ex;
  font-weight: bold;
  color: white;
  border: 1px solid red;
  box-shadow: 0px 0px 4px red;
  border-radius: 2px; }

div.old-ie-warning {
  background: #ffd800;
  padding: 1em; }

div.old-ie-warning p {
  margin: 0;
  line-height: 150%; }

ul#sidepage-menu li a.icon-add {
  background-image: url(icons/add.small.png); }

ul#sidepage-menu li a.icon-book {
  background-image: url(icons/book.small.png); }

ul#sidepage-menu li a.icon-calendar {
  background-image: url(icons/calendar.small.png); }

ul#sidepage-menu li a.icon-categories {
  background-image: url(icons/categories.small.png); }

ul#sidepage-menu li a.icon-clock {
  background-image: url(icons/clock.small.png); }

ul#sidepage-menu li a.icon-connector {
  background-image: url(icons/connector.small.png); }

ul#sidepage-menu li a.icon-counter {
  background-image: url(icons/counter.small.png); }

ul#sidepage-menu li a.icon-facturier {
  background-image: url(icons/facturier.small.png); }

ul#sidepage-menu li a.icon-forms {
  background-image: url(icons/forms.small.png); }

ul#sidepage-menu li a.icon-gis {
  background-image: url(icons/gis.small.png); }

ul#sidepage-menu li a.icon-grid {
  background-image: url(icons/grid.small.png); }

ul#sidepage-menu li a.icon-home {
  background-image: url(icons/home.small.png); }

ul#sidepage-menu li a.icon-mail {
  background-image: url(icons/mail.small.png); }

ul#sidepage-menu li a.icon-management {
  background-image: url(icons/management.small.png); }

ul#sidepage-menu li a.icon-organizational-units {
  background-image: url(icons/organizational-units.small.png); }

ul#sidepage-menu li a.icon-password {
  background-image: url(icons/password.small.png); }

ul#sidepage-menu li a.icon-phone {
  background-image: url(icons/phone.small.png); }

ul#sidepage-menu li a.icon-portal {
  background-image: url(icons/portal.small.png); }

ul#sidepage-menu li a.icon-porte-doc {
  background-image: url(icons/porte-doc.small.png); }

ul#sidepage-menu li a.icon-roles {
  background-image: url(icons/roles.small.png); }

ul#sidepage-menu li a.icon-security {
  background-image: url(icons/security.small.png); }

ul#sidepage-menu li a.icon-services {
  background-image: url(icons/services.small.png); }

ul#sidepage-menu li a.icon-settings {
  background-image: url(icons/settings.small.png); }

ul#sidepage-menu li a.icon-statistics {
  background-image: url(icons/statistics.small.png); }

ul#sidepage-menu li a.icon-submission {
  background-image: url(icons/submission.small.png); }

ul#sidepage-menu li a.icon-system {
  background-image: url(icons/system.small.png); }

ul#sidepage-menu li a.icon-texts {
  background-image: url(icons/texts.small.png); }

ul#sidepage-menu li a.icon-theme {
  background-image: url(icons/theme.small.png); }

ul#sidepage-menu li a.icon-users {
  background-image: url(icons/users.small.png); }

ul#sidepage-menu li a.icon-workflows {
  background-image: url(icons/workflows.small.png); }

ul#sidepage-menu li a.icon-announces {
  background-image: url(icons/announces.small.png); }

ul.apps li.icon-add a {
  background-image: url(icons/add.large.png); }

ul.apps li.icon-add a:hover {
  background-image: url(icons/add.large-hover.png); }

ul.apps li.icon-book a {
  background-image: url(icons/book.large.png); }

ul.apps li.icon-book a:hover {
  background-image: url(icons/book.large-hover.png); }

ul.apps li.icon-calendar a {
  background-image: url(icons/calendar.large.png); }

ul.apps li.icon-calendar a:hover {
  background-image: url(icons/calendar.large-hover.png); }

ul.apps li.icon-categories a {
  background-image: url(icons/categories.large.png); }

ul.apps li.icon-categories a:hover {
  background-image: url(icons/categories.large-hover.png); }

ul.apps li.icon-clock a {
  background-image: url(icons/clock.large.png); }

ul.apps li.icon-clock a:hover {
  background-image: url(icons/clock.large-hover.png); }

ul.apps li.icon-connector a {
  background-image: url(icons/connector.large.png); }

ul.apps li.icon-connector a:hover {
  background-image: url(icons/connector.large-hover.png); }

ul.apps li.icon-counter a {
  background-image: url(icons/counter.large.png); }

ul.apps li.icon-counter a:hover {
  background-image: url(icons/counter.large-hover.png); }

ul.apps li.icon-facturier a {
  background-image: url(icons/facturier.large.png); }

ul.apps li.icon-facturier a:hover {
  background-image: url(icons/facturier.large-hover.png); }

ul.apps li.icon-forms a {
  background-image: url(icons/forms.large.png); }

ul.apps li.icon-forms a:hover {
  background-image: url(icons/forms.large-hover.png); }

ul.apps li.icon-gis a {
  background-image: url(icons/gis.large.png); }

ul.apps li.icon-gis a:hover {
  background-image: url(icons/gis.large-hover.png); }

ul.apps li.icon-grid a {
  background-image: url(icons/grid.large.png); }

ul.apps li.icon-grid a:hover {
  background-image: url(icons/grid.large-hover.png); }

ul.apps li.icon-home a {
  background-image: url(icons/home.large.png); }

ul.apps li.icon-home a:hover {
  background-image: url(icons/home.large-hover.png); }

ul.apps li.icon-mail a {
  background-image: url(icons/mail.large.png); }

ul.apps li.icon-mail a:hover {
  background-image: url(icons/mail.large-hover.png); }

ul.apps li.icon-management a {
  background-image: url(icons/management.large.png); }

ul.apps li.icon-management a:hover {
  background-image: url(icons/management.large-hover.png); }

ul.apps li.icon-organizational-units a {
  background-image: url(icons/organizational-units.large.png); }

ul.apps li.icon-organizational-units a:hover {
  background-image: url(icons/organizational-units.large-hover.png); }

ul.apps li.icon-password a {
  background-image: url(icons/password.large.png); }

ul.apps li.icon-password a:hover {
  background-image: url(icons/password.large-hover.png); }

ul.apps li.icon-phone a {
  background-image: url(icons/phone.large.png); }

ul.apps li.icon-phone a:hover {
  background-image: url(icons/phone.large-hover.png); }

ul.apps li.icon-portal a {
  background-image: url(icons/portal.large.png); }

ul.apps li.icon-portal a:hover {
  background-image: url(icons/portal.large-hover.png); }

ul.apps li.icon-porte-doc a {
  background-image: url(icons/porte-doc.large.png); }

ul.apps li.icon-porte-doc a:hover {
  background-image: url(icons/porte-doc.large-hover.png); }

ul.apps li.icon-roles a {
  background-image: url(icons/roles.large.png); }

ul.apps li.icon-roles a:hover {
  background-image: url(icons/roles.large-hover.png); }

ul.apps li.icon-security a {
  background-image: url(icons/security.large.png); }

ul.apps li.icon-security a:hover {
  background-image: url(icons/security.large-hover.png); }

ul.apps li.icon-services a {
  background-image: url(icons/services.large.png); }

ul.apps li.icon-services a:hover {
  background-image: url(icons/services.large-hover.png); }

ul.apps li.icon-settings a {
  background-image: url(icons/settings.large.png); }

ul.apps li.icon-settings a:hover {
  background-image: url(icons/settings.large-hover.png); }

ul.apps li.icon-statistics a {
  background-image: url(icons/statistics.large.png); }

ul.apps li.icon-statistics a:hover {
  background-image: url(icons/statistics.large-hover.png); }

ul.apps li.icon-submission a {
  background-image: url(icons/submission.large.png); }

ul.apps li.icon-submission a:hover {
  background-image: url(icons/submission.large-hover.png); }

ul.apps li.icon-system a {
  background-image: url(icons/system.large.png); }

ul.apps li.icon-system a:hover {
  background-image: url(icons/system.large-hover.png); }

ul.apps li.icon-texts a {
  background-image: url(icons/texts.large.png); }

ul.apps li.icon-texts a:hover {
  background-image: url(icons/texts.large-hover.png); }

ul.apps li.icon-theme a {
  background-image: url(icons/theme.large.png); }

ul.apps li.icon-theme a:hover {
  background-image: url(icons/theme.large-hover.png); }

ul.apps li.icon-services a {
  background-image: url(icons/services.large.png); }

ul.apps li.icon-users a {
  background-image: url(icons/users.large.png); }

ul.apps li.icon-users a:hover {
  background-image: url(icons/users.large-hover.png); }

ul.apps li.icon-workflows a {
  background-image: url(icons/workflows.large.png); }

ul.apps li.icon-workflows a:hover {
  background-image: url(icons/workflows.large-hover.png); }

ul.apps li.icon-announces a {
  background-image: url(icons/announces.large.png); }

ul.apps li.icon-announces a:hover {
  background-image: url(icons/announces.large-hover.png); }

@media print {
  div#top,
  span#breadcrumb,
  div#header,
  #sidepage-menu {
    display: none; }

  body #main.sidepage-expanded {
    margin: 0; }

  div#header h1 {
    text-shadow: none; } }
#appbar .extra-actions-menu-opener {
  border: none; }
  #appbar .extra-actions-menu-opener::before {
    cursor: pointer;
    content: "\f142";
    /* ellipsis-v */
    font-family: FontAwesome;
    font-size: 140%;
    padding: 2px 1ex;
    margin-right: -0.5ex;
    border: 1px solid transparent;
    border-bottom: 0;
    position: relative;
    z-index: 200;
    top: 2px; }
  #appbar .extra-actions-menu-opener.open::before {
    background: #fafafa;
    border-color: #d0d0d0; }
#appbar .extra-actions-menu {
  background: white;
  padding: 0px;
  list-style: none;
  position: absolute;
  right: -7px;
  margin-top: -24px;
  border: 1px solid #d0d0d0;
  background: #fafafa;
  box-shadow: 0px 1px 1px 2px rgba(0, 0, 0, 0.04);
  z-index: 100;
  display: none;
  min-width: 12em; }
  #appbar .extra-actions-menu.open {
    display: block; }
  #appbar .extra-actions-menu li {
    margin: 0; }
    #appbar .extra-actions-menu li a {
      float: none;
      display: block;
      margin: 0;
      padding: 5px 10px;
      border: none; }
      #appbar .extra-actions-menu li a:hover {
        background: #ccc; }

div.grid {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  clear: none; }

div.grid-1-1 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 100%; }
  @media screen and (max-width: 401px) {
    div.grid-1-1 {
      width: 100%; } }
  div.grid-1-1 + h3, div.grid-1-1 + h4, div.grid-1-1 + p, div.grid-1-1 + div {
    clear: both; }
  div.grid-1-1 textarea, div.grid-1-1 select, div.grid-1-1 input[type=text] {
    width: 100%; }

body div + div.grid-1-1,
div div.grid-1-1 {
  clear: none; }
  body div + div.grid-1-1.newline,
  div div.grid-1-1.newline {
    clear: both; }

div.grid-1-2 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 50%; }
  @media screen and (max-width: 401px) {
    div.grid-1-2 {
      width: 100%; } }
  div.grid-1-2 + h3, div.grid-1-2 + h4, div.grid-1-2 + p, div.grid-1-2 + div {
    clear: both; }
  div.grid-1-2 textarea, div.grid-1-2 select, div.grid-1-2 input[type=text] {
    width: 100%; }

body div + div.grid-1-2,
div div.grid-1-2 {
  clear: none; }
  body div + div.grid-1-2.newline,
  div div.grid-1-2.newline {
    clear: both; }

div.grid-2-2 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 100%; }
  @media screen and (max-width: 401px) {
    div.grid-2-2 {
      width: 100%; } }
  div.grid-2-2 + h3, div.grid-2-2 + h4, div.grid-2-2 + p, div.grid-2-2 + div {
    clear: both; }
  div.grid-2-2 textarea, div.grid-2-2 select, div.grid-2-2 input[type=text] {
    width: 100%; }

body div + div.grid-2-2,
div div.grid-2-2 {
  clear: none; }
  body div + div.grid-2-2.newline,
  div div.grid-2-2.newline {
    clear: both; }

div.grid-1-3 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 33.33333%; }
  @media screen and (max-width: 401px) {
    div.grid-1-3 {
      width: 100%; } }
  div.grid-1-3 + h3, div.grid-1-3 + h4, div.grid-1-3 + p, div.grid-1-3 + div {
    clear: both; }
  div.grid-1-3 textarea, div.grid-1-3 select, div.grid-1-3 input[type=text] {
    width: 100%; }

body div + div.grid-1-3,
div div.grid-1-3 {
  clear: none; }
  body div + div.grid-1-3.newline,
  div div.grid-1-3.newline {
    clear: both; }

div.grid-2-3 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 66.66667%; }
  @media screen and (max-width: 401px) {
    div.grid-2-3 {
      width: 100%; } }
  div.grid-2-3 + h3, div.grid-2-3 + h4, div.grid-2-3 + p, div.grid-2-3 + div {
    clear: both; }
  div.grid-2-3 textarea, div.grid-2-3 select, div.grid-2-3 input[type=text] {
    width: 100%; }

body div + div.grid-2-3,
div div.grid-2-3 {
  clear: none; }
  body div + div.grid-2-3.newline,
  div div.grid-2-3.newline {
    clear: both; }

div.grid-3-3 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 100%; }
  @media screen and (max-width: 401px) {
    div.grid-3-3 {
      width: 100%; } }
  div.grid-3-3 + h3, div.grid-3-3 + h4, div.grid-3-3 + p, div.grid-3-3 + div {
    clear: both; }
  div.grid-3-3 textarea, div.grid-3-3 select, div.grid-3-3 input[type=text] {
    width: 100%; }

body div + div.grid-3-3,
div div.grid-3-3 {
  clear: none; }
  body div + div.grid-3-3.newline,
  div div.grid-3-3.newline {
    clear: both; }

div.grid-1-4 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 25%; }
  @media screen and (max-width: 601px) {
    div.grid-1-4 {
      width: 50%; } }
  @media screen and (max-width: 401px) {
    div.grid-1-4 {
      width: 100%; } }
  div.grid-1-4 + h3, div.grid-1-4 + h4, div.grid-1-4 + p, div.grid-1-4 + div {
    clear: both; }
  div.grid-1-4 textarea, div.grid-1-4 select, div.grid-1-4 input[type=text] {
    width: 100%; }

body div + div.grid-1-4,
div div.grid-1-4 {
  clear: none; }
  body div + div.grid-1-4.newline,
  div div.grid-1-4.newline {
    clear: both; }

div.grid-2-4 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 50%; }
  @media screen and (max-width: 601px) {
    div.grid-2-4 {
      width: 50%; } }
  @media screen and (max-width: 401px) {
    div.grid-2-4 {
      width: 100%; } }
  div.grid-2-4 + h3, div.grid-2-4 + h4, div.grid-2-4 + p, div.grid-2-4 + div {
    clear: both; }
  div.grid-2-4 textarea, div.grid-2-4 select, div.grid-2-4 input[type=text] {
    width: 100%; }

body div + div.grid-2-4,
div div.grid-2-4 {
  clear: none; }
  body div + div.grid-2-4.newline,
  div div.grid-2-4.newline {
    clear: both; }

div.grid-3-4 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 75%; }
  @media screen and (max-width: 601px) {
    div.grid-3-4 {
      width: 100%; } }
  @media screen and (max-width: 401px) {
    div.grid-3-4 {
      width: 100%; } }
  div.grid-3-4 + h3, div.grid-3-4 + h4, div.grid-3-4 + p, div.grid-3-4 + div {
    clear: both; }
  div.grid-3-4 textarea, div.grid-3-4 select, div.grid-3-4 input[type=text] {
    width: 100%; }

body div + div.grid-3-4,
div div.grid-3-4 {
  clear: none; }
  body div + div.grid-3-4.newline,
  div div.grid-3-4.newline {
    clear: both; }

div.grid-4-4 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 100%; }
  @media screen and (max-width: 601px) {
    div.grid-4-4 {
      width: 100%; } }
  @media screen and (max-width: 401px) {
    div.grid-4-4 {
      width: 100%; } }
  div.grid-4-4 + h3, div.grid-4-4 + h4, div.grid-4-4 + p, div.grid-4-4 + div {
    clear: both; }
  div.grid-4-4 textarea, div.grid-4-4 select, div.grid-4-4 input[type=text] {
    width: 100%; }

body div + div.grid-4-4,
div div.grid-4-4 {
  clear: none; }
  body div + div.grid-4-4.newline,
  div div.grid-4-4.newline {
    clear: both; }

div.grid-1-6 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 16.66667%; }
  @media screen and (max-width: 601px) {
    div.grid-1-6 {
      width: 33.33333%; } }
  @media screen and (max-width: 401px) {
    div.grid-1-6 {
      width: 100%; } }
  div.grid-1-6 + h3, div.grid-1-6 + h4, div.grid-1-6 + p, div.grid-1-6 + div {
    clear: both; }
  div.grid-1-6 textarea, div.grid-1-6 select, div.grid-1-6 input[type=text] {
    width: 100%; }

body div + div.grid-1-6,
div div.grid-1-6 {
  clear: none; }
  body div + div.grid-1-6.newline,
  div div.grid-1-6.newline {
    clear: both; }

div.grid-2-6 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 33.33333%; }
  @media screen and (max-width: 601px) {
    div.grid-2-6 {
      width: 33.33333%; } }
  @media screen and (max-width: 401px) {
    div.grid-2-6 {
      width: 100%; } }
  div.grid-2-6 + h3, div.grid-2-6 + h4, div.grid-2-6 + p, div.grid-2-6 + div {
    clear: both; }
  div.grid-2-6 textarea, div.grid-2-6 select, div.grid-2-6 input[type=text] {
    width: 100%; }

body div + div.grid-2-6,
div div.grid-2-6 {
  clear: none; }
  body div + div.grid-2-6.newline,
  div div.grid-2-6.newline {
    clear: both; }

div.grid-3-6 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 50%; }
  @media screen and (max-width: 601px) {
    div.grid-3-6 {
      width: 50%; } }
  @media screen and (max-width: 401px) {
    div.grid-3-6 {
      width: 100%; } }
  div.grid-3-6 + h3, div.grid-3-6 + h4, div.grid-3-6 + p, div.grid-3-6 + div {
    clear: both; }
  div.grid-3-6 textarea, div.grid-3-6 select, div.grid-3-6 input[type=text] {
    width: 100%; }

body div + div.grid-3-6,
div div.grid-3-6 {
  clear: none; }
  body div + div.grid-3-6.newline,
  div div.grid-3-6.newline {
    clear: both; }

div.grid-4-6 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 66.66667%; }
  @media screen and (max-width: 601px) {
    div.grid-4-6 {
      width: 66.66667%; } }
  @media screen and (max-width: 401px) {
    div.grid-4-6 {
      width: 100%; } }
  div.grid-4-6 + h3, div.grid-4-6 + h4, div.grid-4-6 + p, div.grid-4-6 + div {
    clear: both; }
  div.grid-4-6 textarea, div.grid-4-6 select, div.grid-4-6 input[type=text] {
    width: 100%; }

body div + div.grid-4-6,
div div.grid-4-6 {
  clear: none; }
  body div + div.grid-4-6.newline,
  div div.grid-4-6.newline {
    clear: both; }

div.grid-5-6 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 83.33333%; }
  @media screen and (max-width: 601px) {
    div.grid-5-6 {
      width: 66.66667%; } }
  @media screen and (max-width: 401px) {
    div.grid-5-6 {
      width: 100%; } }
  div.grid-5-6 + h3, div.grid-5-6 + h4, div.grid-5-6 + p, div.grid-5-6 + div {
    clear: both; }
  div.grid-5-6 textarea, div.grid-5-6 select, div.grid-5-6 input[type=text] {
    width: 100%; }

body div + div.grid-5-6,
div div.grid-5-6 {
  clear: none; }
  body div + div.grid-5-6.newline,
  div div.grid-5-6.newline {
    clear: both; }

div.grid-6-6 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 100%; }
  @media screen and (max-width: 601px) {
    div.grid-6-6 {
      width: 100%; } }
  @media screen and (max-width: 401px) {
    div.grid-6-6 {
      width: 100%; } }
  div.grid-6-6 + h3, div.grid-6-6 + h4, div.grid-6-6 + p, div.grid-6-6 + div {
    clear: both; }
  div.grid-6-6 textarea, div.grid-6-6 select, div.grid-6-6 input[type=text] {
    width: 100%; }

body div + div.grid-6-6,
div div.grid-6-6 {
  clear: none; }
  body div + div.grid-6-6.newline,
  div div.grid-6-6.newline {
    clear: both; }

div.grid-1-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 8.33333%; }
  @media screen and (max-width: 601px) {
    div.grid-1-12 {
      width: 33.33333%; } }
  @media screen and (max-width: 401px) {
    div.grid-1-12 {
      width: 100%; } }
  div.grid-1-12 + h3, div.grid-1-12 + h4, div.grid-1-12 + p, div.grid-1-12 + div {
    clear: both; }
  div.grid-1-12 textarea, div.grid-1-12 select, div.grid-1-12 input[type=text] {
    width: 100%; }

body div + div.grid-1-12,
div div.grid-1-12 {
  clear: none; }
  body div + div.grid-1-12.newline,
  div div.grid-1-12.newline {
    clear: both; }

div.grid-2-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 16.66667%; }
  @media screen and (max-width: 601px) {
    div.grid-2-12 {
      width: 33.33333%; } }
  @media screen and (max-width: 401px) {
    div.grid-2-12 {
      width: 100%; } }
  div.grid-2-12 + h3, div.grid-2-12 + h4, div.grid-2-12 + p, div.grid-2-12 + div {
    clear: both; }
  div.grid-2-12 textarea, div.grid-2-12 select, div.grid-2-12 input[type=text] {
    width: 100%; }

body div + div.grid-2-12,
div div.grid-2-12 {
  clear: none; }
  body div + div.grid-2-12.newline,
  div div.grid-2-12.newline {
    clear: both; }

div.grid-3-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 25%; }
  @media screen and (max-width: 601px) {
    div.grid-3-12 {
      width: 33.33333%; } }
  @media screen and (max-width: 401px) {
    div.grid-3-12 {
      width: 100%; } }
  div.grid-3-12 + h3, div.grid-3-12 + h4, div.grid-3-12 + p, div.grid-3-12 + div {
    clear: both; }
  div.grid-3-12 textarea, div.grid-3-12 select, div.grid-3-12 input[type=text] {
    width: 100%; }

body div + div.grid-3-12,
div div.grid-3-12 {
  clear: none; }
  body div + div.grid-3-12.newline,
  div div.grid-3-12.newline {
    clear: both; }

div.grid-4-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 33.33333%; }
  @media screen and (max-width: 601px) {
    div.grid-4-12 {
      width: 33.33333%; } }
  @media screen and (max-width: 401px) {
    div.grid-4-12 {
      width: 100%; } }
  div.grid-4-12 + h3, div.grid-4-12 + h4, div.grid-4-12 + p, div.grid-4-12 + div {
    clear: both; }
  div.grid-4-12 textarea, div.grid-4-12 select, div.grid-4-12 input[type=text] {
    width: 100%; }

body div + div.grid-4-12,
div div.grid-4-12 {
  clear: none; }
  body div + div.grid-4-12.newline,
  div div.grid-4-12.newline {
    clear: both; }

div.grid-5-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 41.66667%; }
  @media screen and (max-width: 601px) {
    div.grid-5-12 {
      width: 50%; } }
  @media screen and (max-width: 401px) {
    div.grid-5-12 {
      width: 100%; } }
  div.grid-5-12 + h3, div.grid-5-12 + h4, div.grid-5-12 + p, div.grid-5-12 + div {
    clear: both; }
  div.grid-5-12 textarea, div.grid-5-12 select, div.grid-5-12 input[type=text] {
    width: 100%; }

body div + div.grid-5-12,
div div.grid-5-12 {
  clear: none; }
  body div + div.grid-5-12.newline,
  div div.grid-5-12.newline {
    clear: both; }

div.grid-6-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 50%; }
  @media screen and (max-width: 601px) {
    div.grid-6-12 {
      width: 50%; } }
  @media screen and (max-width: 401px) {
    div.grid-6-12 {
      width: 100%; } }
  div.grid-6-12 + h3, div.grid-6-12 + h4, div.grid-6-12 + p, div.grid-6-12 + div {
    clear: both; }
  div.grid-6-12 textarea, div.grid-6-12 select, div.grid-6-12 input[type=text] {
    width: 100%; }

body div + div.grid-6-12,
div div.grid-6-12 {
  clear: none; }
  body div + div.grid-6-12.newline,
  div div.grid-6-12.newline {
    clear: both; }

div.grid-7-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 58.33333%; }
  @media screen and (max-width: 601px) {
    div.grid-7-12 {
      width: 50%; } }
  @media screen and (max-width: 401px) {
    div.grid-7-12 {
      width: 100%; } }
  div.grid-7-12 + h3, div.grid-7-12 + h4, div.grid-7-12 + p, div.grid-7-12 + div {
    clear: both; }
  div.grid-7-12 textarea, div.grid-7-12 select, div.grid-7-12 input[type=text] {
    width: 100%; }

body div + div.grid-7-12,
div div.grid-7-12 {
  clear: none; }
  body div + div.grid-7-12.newline,
  div div.grid-7-12.newline {
    clear: both; }

div.grid-8-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 66.66667%; }
  @media screen and (max-width: 601px) {
    div.grid-8-12 {
      width: 66.66667%; } }
  @media screen and (max-width: 401px) {
    div.grid-8-12 {
      width: 100%; } }
  div.grid-8-12 + h3, div.grid-8-12 + h4, div.grid-8-12 + p, div.grid-8-12 + div {
    clear: both; }
  div.grid-8-12 textarea, div.grid-8-12 select, div.grid-8-12 input[type=text] {
    width: 100%; }

body div + div.grid-8-12,
div div.grid-8-12 {
  clear: none; }
  body div + div.grid-8-12.newline,
  div div.grid-8-12.newline {
    clear: both; }

div.grid-9-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 75%; }
  @media screen and (max-width: 601px) {
    div.grid-9-12 {
      width: 66.66667%; } }
  @media screen and (max-width: 401px) {
    div.grid-9-12 {
      width: 100%; } }
  div.grid-9-12 + h3, div.grid-9-12 + h4, div.grid-9-12 + p, div.grid-9-12 + div {
    clear: both; }
  div.grid-9-12 textarea, div.grid-9-12 select, div.grid-9-12 input[type=text] {
    width: 100%; }

body div + div.grid-9-12,
div div.grid-9-12 {
  clear: none; }
  body div + div.grid-9-12.newline,
  div div.grid-9-12.newline {
    clear: both; }

div.grid-10-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 83.33333%; }
  @media screen and (max-width: 601px) {
    div.grid-10-12 {
      width: 66.66667%; } }
  @media screen and (max-width: 401px) {
    div.grid-10-12 {
      width: 100%; } }
  div.grid-10-12 + h3, div.grid-10-12 + h4, div.grid-10-12 + p, div.grid-10-12 + div {
    clear: both; }
  div.grid-10-12 textarea, div.grid-10-12 select, div.grid-10-12 input[type=text] {
    width: 100%; }

body div + div.grid-10-12,
div div.grid-10-12 {
  clear: none; }
  body div + div.grid-10-12.newline,
  div div.grid-10-12.newline {
    clear: both; }

div.grid-11-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 91.66667%; }
  @media screen and (max-width: 601px) {
    div.grid-11-12 {
      width: 66.66667%; } }
  @media screen and (max-width: 401px) {
    div.grid-11-12 {
      width: 100%; } }
  div.grid-11-12 + h3, div.grid-11-12 + h4, div.grid-11-12 + p, div.grid-11-12 + div {
    clear: both; }
  div.grid-11-12 textarea, div.grid-11-12 select, div.grid-11-12 input[type=text] {
    width: 100%; }

body div + div.grid-11-12,
div div.grid-11-12 {
  clear: none; }
  body div + div.grid-11-12.newline,
  div div.grid-11-12.newline {
    clear: both; }

div.grid-12-12 {
  float: left;
  box-sizing: border-box;
  padding-right: 1em;
  width: 100%; }
  @media screen and (max-width: 601px) {
    div.grid-12-12 {
      width: 100%; } }
  @media screen and (max-width: 401px) {
    div.grid-12-12 {
      width: 100%; } }
  div.grid-12-12 + h3, div.grid-12-12 + h4, div.grid-12-12 + p, div.grid-12-12 + div {
    clear: both; }
  div.grid-12-12 textarea, div.grid-12-12 select, div.grid-12-12 input[type=text] {
    width: 100%; }

body div + div.grid-12-12,
div div.grid-12-12 {
  clear: none; }
  body div + div.grid-12-12.newline,
  div div.grid-12-12.newline {
    clear: both; }

body .ui-front {
  z-index: 1000; }

.ui-helper-hidden {
  display: none; }

.ui-helper-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }

.ui-widget-content {
  border: 1px solid #aaa;
  background: white; }
  .ui-widget-content .ui-widget-header {
    border: 1px solid #aaa;
    background: #ccc;
    position: relative;
    text-align: center;
    padding: 3px; }
    .ui-widget-content .ui-widget-header a {
      color: #333; }

.ui-datepicker {
  display: none;
  padding: .2em .2em 0; }
  .ui-datepicker select.ui-datepicker-month, .ui-datepicker select.ui-datepicker-year {
    width: 49%; }
  .ui-datepicker .ui-datepicker-title {
    margin: 0 2.5em; }
  .ui-datepicker table {
    width: 100%;
    border-collapse: collapse; }
    .ui-datepicker table td {
      text-align: right; }
      .ui-datepicker table td a {
        background: #eee;
        border: 1px solid #aaa;
        display: block;
        padding: 0.4ex 1ex; }
        .ui-datepicker table td a:hover {
          border-color: #666; }
  .ui-datepicker a {
    border-bottom: 0; }
  .ui-datepicker .ui-datepicker-prev {
    display: block;
    position: absolute;
    left: 0.5ex;
    cursor: pointer; }
    .ui-datepicker .ui-datepicker-prev::after {
      font-family: FontAwesome;
      content: "\f060";
      /* fa-arrow-left */ }
    .ui-datepicker .ui-datepicker-prev span {
      display: none; }
  .ui-datepicker .ui-datepicker-next {
    display: block;
    position: absolute;
    right: 0.5ex;
    cursor: pointer; }
    .ui-datepicker .ui-datepicker-next::after {
      font-family: FontAwesome;
      content: "\f061";
      /* fa-arrow-right */ }
    .ui-datepicker .ui-datepicker-next span {
      display: none; }

/* dialog styling */
.ui-helper-clearfix {
  min-height: 0; }
  .ui-helper-clearfix::before, .ui-helper-clearfix::after {
    content: "";
    display: table;
    border-collapse: collapse; }
  .ui-helper-clearfix::after {
    clear: both; }

div.ui-widget-overlay {
  background: #333;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  opacity: 0.3;
  z-index: 1000; }

.ui-widget {
  font-size: 1.1em; }
  .ui-widget .ui-widget {
    font-size: 1em; }

div.ui-dialog {
  border: 0;
  outline: 0;
  background: white;
  box-shadow: #666666 0px 0px 20px 2px;
  padding: 0;
  border-radius: 0;
  max-width: 80%;
  min-width: 30%;
  position: absolute; }
  div.ui-dialog .ui-dialog-titlebar {
    background: #eee;
    border-radius: 0;
    border: none;
    position: relative;
    padding: 0.4em 1em;
    cursor: move;
    text-align: left; }
    div.ui-dialog .ui-dialog-titlebar .ui-dialog-title {
      font-size: 130%;
      font-weight: normal; }
    div.ui-dialog .ui-dialog-titlebar .ui-dialog-titlebar-close {
      position: absolute;
      right: .3em;
      height: 20px;
      min-width: 20px;
      padding: 0;
      color: #333;
      margin-right: 0;
      outline: none; }
      div.ui-dialog .ui-dialog-titlebar .ui-dialog-titlebar-close .ui-icon-closethick::after {
        content: "\f00d";
        /* fa-times */
        font-family: FontAwesome;
        padding-top: 5px;
        display: block; }
      div.ui-dialog .ui-dialog-titlebar .ui-dialog-titlebar-close .ui-button-text {
        display: block;
        text-indent: -9999999px; }
    div.ui-dialog .ui-dialog-titlebar button {
      padding: 0;
      border: 1px solid transparent;
      background: transparent;
      box-shadow: none;
      cursor: pointer; }
  div.ui-dialog .ui-widget-content {
    position: relative;
    border: 0;
    padding: .5em 1em;
    background: none;
    overflow: auto; }
  div.ui-dialog .ui-dialog-buttonpane {
    position: relative;
    background: #eee;
    border-top: 1px solid #aaaaaa;
    margin-top: 0.5em;
    padding: 0.3em 1em 0.5em 0.4em; }
    div.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
      float: right; }
    div.ui-dialog .ui-dialog-buttonpane button {
      margin: 0.5em 0 0.5em 1em; }
  div.ui-dialog form p input,
  div.ui-dialog form p select,
  div.ui-dialog form p textarea {
    width: 100%; }
  div.ui-dialog form p input[type=radio], div.ui-dialog form p input[type=checkbox] {
    width: auto; }

.ui-tooltip {
  display: inline-block;
  box-shadow: #666 0px 0px 4px 0px;
  z-index: 100000; }
  .ui-tooltip div.ui-tooltip-content {
    background: white;
    padding: 1ex; }

ul.ui-autocomplete {
  position: absolute;
  top: 0;
  left: 0;
  cursor: default;
  list-style: none;
  margin: 0;
  padding: 0;
  max-height: 15em;
  overflow-y: scroll;
  overflow-x: hidden; }
  ul.ui-autocomplete li {
    margin: 0;
    padding: 0 1ex;
    position: relative;
    min-height: 0; }
    ul.ui-autocomplete li:hover {
      background: #eee; }

label {
  margin-bottom: 0; }

form div.widget {
  margin-bottom: 2ex; }

div.errornotice p {
  margin: 1ex 0; }

div.error {
  color: black;
  font-weight: normal;
  background: transparent;
  padding-left: 0px;
  margin-left: 2px; }

div.error::before {
  content: "\f071";
  /* fa-exclamation-triangle */
  font-family: FontAwesome;
  padding-right: 1ex; }

span.required {
  margin-left: 0.7ex;
  position: relative;
  top: -0.2ex; }

div.widget div.title {
  margin-bottom: 0; }

div.buttons {
  margin-top: 2em; }

div.buttons div {
  display: inline-block; }
  div.buttons div input[name="submit"] {
    font-weight: bold; }

a.button {
  padding-bottom: calc(1ex + 1px);
  line-height: 2.5em; }

a.button, button, input[type=submit], div.buttons input {
  padding: 5px 15px;
  cursor: pointer;
  border: 0px solid #aaa;
  transition: all 0.2s ease;
  height: 2.5em;
  vertical-align: middle;
  border-radius: 3px;
  font-weight: bold; }

a.button, button, input[type=submit], div.buttons input {
  background: #5B616B;
  border: 1px solid #5B616B;
  color: #ffffff;
  transition: background 0.3s linear; }
  a.button:hover, button:hover, input[type=submit]:hover, div.buttons input:hover {
    background: #2c2f34; }
  a.button:active, button:active, input[type=submit]:active, div.buttons input:active {
    background: #44484f; }
  a.button:focus, button:focus, input[type=submit]:focus, div.buttons input:focus {
    box-shadow: 0 0 3px #2e444f, 0 0 7px #2e444f; }

a.cancel-button, button.cancel-button, div.buttons .cancel-button input, div.buttons .cancel-button button {
  background: #636363;
  border-color: #636363; }
  a.cancel-button:hover, button.cancel-button:hover, div.buttons .cancel-button input:hover, div.buttons .cancel-button button:hover {
    background: #303030; }
  a.cancel-button:active, button.cancel-button:active, div.buttons .cancel-button input:active, div.buttons .cancel-button button:active {
    background: #4a4a4a; }

a.delete-button, button.delete-button, div.buttons .delete-button input, div.buttons .delete-button button {
  background: #CD2026;
  border-color: #CD2026; }
  a.delete-button:hover, button.delete-button:hover, div.buttons .delete-button input:hover, div.buttons .delete-button button:hover {
    background: #751216; }
  a.delete-button:active, button.delete-button:active, div.buttons .delete-button input:active, div.buttons .delete-button button:active {
    background: #a1191e; }

a.submit-button, button.submit-button, div.buttons .submit-button input, div.buttons .submit-button button {
  background: #215D9C;
  border-color: #215D9C; }
  a.submit-button:hover, button.submit-button:hover, div.buttons .submit-button input:hover, div.buttons .submit-button button:hover {
    background: #0f2b48; }
  a.submit-button:active, button.submit-button:active, div.buttons .submit-button input:active, div.buttons .submit-button button:active {
    background: #184472; }

div.ui-dialog button.ui-button-disabled,
div#content button:disabled,
input[type=submit]:disabled {
  border-color: #888;
  color: #888;
  background: #f3f3f3;
  pointer-events: none;
  box-shadow: none;
  cursor: not-allowed; }

input, input[type="text"], input[type="url"], input[type="email"], input[type="password"], input[type="url"], input[type="tel"], input[type="number"], input[type="search"], input[type="file"], input[type="date"], input[type="datetime-local"], input[type="month"], input[type="time"], input[type="week"], textarea, select {
  border: 1px solid #AAA;
  border-radius: 0px;
  box-sizing: border-box;
  margin: 0.2em 0px;
  outline: medium none;
  padding: 0.7ex 0.7em;
  max-width: 100%; }
  input:focus, input[type="text"]:focus, input[type="url"]:focus, input[type="email"]:focus, input[type="password"]:focus, input[type="url"]:focus, input[type="tel"]:focus, input[type="number"]:focus, input[type="search"]:focus, input[type="file"]:focus, input[type="date"]:focus, input[type="datetime-local"]:focus, input[type="month"]:focus, input[type="time"]:focus, input[type="week"]:focus, textarea:focus, select:focus {
    box-shadow: 0 0 0px 1px #1999cd; }
  input.disabled, input[disabled], input[type="text"].disabled, input[type="text"][disabled], input[type="url"].disabled, input[type="url"][disabled], input[type="email"].disabled, input[type="email"][disabled], input[type="password"].disabled, input[type="password"][disabled], input[type="url"].disabled, input[type="url"][disabled], input[type="tel"].disabled, input[type="tel"][disabled], input[type="number"].disabled, input[type="number"][disabled], input[type="search"].disabled, input[type="search"][disabled], input[type="file"].disabled, input[type="file"][disabled], input[type="date"].disabled, input[type="date"][disabled], input[type="datetime-local"].disabled, input[type="datetime-local"][disabled], input[type="month"].disabled, input[type="month"][disabled], input[type="time"].disabled, input[type="time"][disabled], input[type="week"].disabled, input[type="week"][disabled], textarea.disabled, textarea[disabled], select.disabled, select[disabled] {
    background: #eee; }

input[type="radio"]:focus, input[type="checkbox"]:focus {
  box-shadow: none; }

input[readonly], select[readonly], textarea[readonly] {
  border-width: 0 0 1px 0; }

div.date input[readonly] {
  border-width: 1px; }

input[type=file] {
  border: none;
  padding-left: 0; }

select {
  background: white;
  -webkit-appearance: none;
  -moz-appearance: none;
  -ms-appearance: none;
  -o-appearance: none;
  appearance: none;
  padding-right: 4em;
  background-image: url(arrow-down.svg);
  background-position: right 1.3rem center;
  background-repeat: no-repeat;
  background-size: 1rem auto; }

select[multiple=multiple] {
  background: white;
  padding-right: 0; }

input[type="checkbox"],
input[type="radio"] {
  margin-right: 1ex;
  margin-bottom: 1ex; }

div.content label {
  margin-right: 1em; }

div.widget div.content ul {
  padding: 0;
  margin: 0;
  list-style: none; }

span.helptext,
div.hint {
  display: block;
  font-size: 80%; }

form p label {
  display: block; }

div.a2-block form input,
div.a2-block form select {
  width: 100%; }

div.a2-block form input[type=radio] {
  width: auto; }

div.a2-block form input[type=submit] {
  width: auto;
  min-width: 20ex; }

div.a2-block ul#id_edit-profile-title {
  margin-left: 1em;
  margin-top: -1ex; }
  div.a2-block ul#id_edit-profile-title li {
    display: inline-block;
    margin-right: 2em; }
  div.a2-block ul#id_edit-profile-title label {
    font-weight: normal; }

form ul.errorlist {
  padding: 0;
  margin: 2em 0 0 0;
  list-style: none; }
  form ul.errorlist li::before {
    content: "\f06a";
    font-family: FontAwesome;
    padding-right: 1ex; }

/* fieldsets */
fieldset.gadjo-foldable legend.gadjo-foldable-widget {
  border-bottom: 1px solid #aaa;
  cursor: pointer;
  display: block;
  font-weight: bold;
  padding: 1ex 0 0;
  width: 100%; }

fieldset.gadjo-foldable legend.gadjo-foldable-widget:after {
  font-family: FontAwesome;
  content: "\f106";
  /* angle-up */
  position: absolute;
  right: 1em; }

fieldset.gadjo-foldable.gadjo-folded legend.gadjo-foldable-widget:after {
  content: "\f107";
  /* angle-down */ }

fieldset.gadjo-foldable {
  padding: 1ex 0 0 0;
  border: 0; }

.gadjo-foldable.gadjo-folded > .gadjo-folding {
  display: none; }

/* form.as_p */
form p {
  margin: 0 0 1em 0; }

form p label {
  display: block; }

form p.required label:after {
  padding-left: 1ex;
  content: "*";
  color: red; }

form p label {
  margin-bottom: 0.3ex; }

/* form.small */
form.small p input {
  margin-left: 0; }

form.small p {
  margin-bottom: 0.5em; }

form.small label {
  width: 200px;
  display: inline-block; }

form.small a.button,
form.small button {
  margin-left: 205px;
  display: inline-block; }

form.small button + button,
form.small button + a.button {
  margin-left: 1em; }

/*# sourceMappingURL=gadjo.css.map */
