{% load i18n gadjo staticfiles %}<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8"/>
    <title>{% block page-title %}{% endblock %}</title>
    <link rel="stylesheet" type="text/css" media="all" href="{% static "css/gadjo.css" %}"/>
    {% block gadjo-js %}
    <script src="{% xstatic 'jquery' 'jquery.min.js' %}"></script>
    <script src="{% xstatic 'jquery-ui' 'jquery-ui.min.js' %}"></script>
    <script src="{% static "js/gadjo.js" %}"></script>
    {% endblock %}
    {{ media }}
    {% block css %}
    <link rel="stylesheet" type="text/css" media="all" href="{% static "css/style.css" %}"/>
    {% endblock %}
    {% block extrascripts %}
    {% endblock %}
  </head>
  <body data-gadjo="true" {% block bodyargs %}{% endblock %}>
  <div id="top">
    {% block sidepage %}
    <div id="sidepage">
      <span id="applabel"> </span>
    </div>
    {% endblock %}
    {% block user-links %}
    <ul class="user-info">
  {% if user.is_authenticated %}
  <li class="ui-name">{{ user.get_full_name }}</li>
  <li class="ui-logout"><a href="{% block logout-url %}index.html{% endblock %}">{% trans "Logout" %}</a></li>
          {% endif %}
  </ul>
        {% endblock %}
  </div>
  <div id="main">
    <div id="header">
      {% block site-header %}
        <h1>{% block site-title %}{% endblock %}</h1>
        {% block subheader %}{% endblock %}
      {% endblock %}
    </div>

{% block old-ie-warning %}
<!--[if lt IE 9]>
<div class="old-ie-warning">
  {% blocktrans %}
  <p><strong>Do you know your web browser is obsolete?</strong>  We recommend
  you to <a href="http://windows.microsoft.com/en-us/internet-explorer/download-ie">update
  your web browser</a> or to <a href="http://browsehappy.com/">use
  different web browsers</a> as some features may not work.
  {% endblocktrans %}
</div>
<![endif]-->
{% endblock %}

    <div id="main-content" {% block main-content-attributes %}{% endblock %}>
      {% block main-content %}
      <div id="more-user-links">
        {% block more-user-links %}
          <span id="breadcrumb">
          {% block breadcrumb %}
          <a href="{% block homepage-url %}/{% endblock %}">{% block homepage-title %}{% trans "Homepage" %}{% endblock %}</a>
          {% endblock %}
          </span>
        {% endblock %}
      </div>
      <div id="content">

        <div id="appbar">
          {% block appbar %}
          {% endblock %}
        </div>

{% block messages %}
{% if messages %}
<ul class="messages">
    {% for message in messages %}
    <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
    {% endfor %}
</ul>
{% endif %}
{% endblock %}

        {% block beforecontent %}
        {% endblock %}

        {% block content %}
        {% endblock %}
        <br style="clear: both;"/>

        {% block aftercontent %}
        {% endblock %}

      </div> <!-- #content -->
      {% endblock %}
    </div> <!-- #main-content -->

    {% block after-main-content %}
    {% endblock %}

  </div> <!-- #main -->


  <div id="footer">
    {% block footer %}
      Copyright &copy; 2014 Entr'ouvert
    {% endblock %}
  </div>

  {% block page-end %}
  {% endblock %}
  </body>
</html>
