{% load i18n %}
{{ form.non_field_errors }}
{% for field in form %}
  {% if field.is_hidden %}
    {% if field.errors %}
      <ul class="errorlist">
        {% for error in field.errors %}
        <li>
          {% blocktrans with name=field.name %}(Hidden field {{name}}) {{ error }}{% endblocktrans %}
        </li>
        {% endfor %}
      </ul>
    {% endif %}
    {{ field }}
  {% endif %}
{% endfor %}
{% for field in form %}
  {% if not field.is_hidden %}
  <p {% if field.css_classes %}class="{{ field.css_classes }}"{% endif %}>
     {{ field.label_tag }}
     {% if field.errors %}
       <ul class="errorlist">
         {% for error in field.errors %}
           <li>{{ error }}</li>
         {% endfor %}
       </ul>
     {% endif %}
     {{ field }}
     {% if field.help_text %}
       <span class="helptext">{{ field.help_text }}</span>
     {% endif %}
  </p>
  {% endif %}
{% endfor %}
